<?php 
class Common_db extends CI_Model {

    function __construct()
    {
        // Call the Model constructor
        parent::__construct();
    }
    
    function insert($table, $data) {
        $this->db->insert($table, $data);
        return $this->db->insert_id();
    }
    
    function update($id, $table, $data) {
        if (is_array($id)) {
            $this->db->where_in('id', $id);
        } else {
            $this->db->where('id', $id);
        }
        $this->db->update($table, $data);
		
		return $id;
    }
    
    function delete($id, $table, $other_tables = array()) {
        $this->remove($id, $table, $other_tables);
    }
    
    function remove($id, $table, $other_tables = array()) {
        if (is_array($id)) {
            $this->db->where_in('id', $id);
        } else {
            $this->db->where('id', $id);
        }
        $this->db->delete($table);
        
        if (count($other_tables)) {
            if (is_array($id)) {
                $this->db->where_in($table.'_id', $id);
            } else {
                $this->db->where($table.'_id', $id);
            }
            $this->db->delete($other_tables);
        }
    }
    
    function get_row($id, $table, $details = TRUE, $mtm_table = array(), $otm_table = array(), $except_table = "") {
        $this->db->where('id', $id);
        $query = $this->db->get($table);
        if ($query->num_rows()) {
            $row = $query->row_array();
            
            if ($details) {
                foreach ($row as $index=>$value) {
                    if ("_id" == substr($index, -3)) {
                        $temp_table = substr($index, 0, -3);
                        if ($temp_table == $except_table)
                            continue;
                        if ($temp_table != "parent") {
                            $row[$temp_table] = $this->get_row($value, $temp_table, TRUE, array(), array(), $table);
                        } else {
                            $row[$temp_table] = $this->get_row($value, $table, TRUE, array(), array(), $table);
                        }
                    }
                }
				
				if (isset($row['date'])) {
					$row['timestamp'] = $row['date'];
					$row['en_date'] = date('j F Y', $row['timestamp']);
					
					$pattern = array('/January/', '/February/', '/March/', '/April/', '/May/', '/June/', '/July/', '/August/', '/September/', '/October/', '/November/', '/December/');
					$replacement = array('يناير', 'فبراير', 'مارس', 'إبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر');
					
					$row['date'] = preg_replace($pattern, $replacement, $row['en_date']) . ' م';
				}
				
                if (count($mtm_table)) {
                    foreach ($mtm_table as $temp_table) {
                        if ($temp_table == $except_table)
                            continue;
						$temp_array = array($table,
                                 $temp_table);
                        sort($temp_array);
                        $link_table = $temp_array[0]."_link_".$temp_array[1];
                        $this->db->where($table."_id", $id);
                        $temp_query = $this->db->get($link_table);
                        if ($temp_query->num_rows()) {
                            $row[$temp_table] = array();
                            foreach ($temp_query->result_array() as $temp_row) {
                                $row[$temp_table][] = $this->get_row($temp_row[$temp_table.'_id'], $temp_table, TRUE, array(), array(), $table);
                            }
                        }
                    }
                }
				
                if (count($otm_table)) {
                    foreach ($otm_table as $temp_table) {
                        if ($temp_table == $except_table)
                            continue;
                        $this->db->where($table."_id", $id);
                        $this->db->order_by("id");
                        $temp_query = $this->db->get($temp_table);
                        if ($temp_query->num_rows()) {
                            $row[$temp_table] = array();
                            foreach ($temp_query->result_array() as $temp_row) {
                                $row[$temp_table][] = $this->get_row($temp_row['id'], $temp_table, TRUE, array(), array(), $table);
                            }
                        }
                    }
                }
            }
            
            return $row;
        } else {
            return FALSE;
        }
    }
    
    function get_rows($table, $ids = array(), $details = TRUE, $order_by = "id asc", $limit = FALSE, $other_tables = array()) {
        if (count($ids)) {
            $rows = array();
            foreach ($ids as $id) {
                $rows[] = $this->get_row($id, $table, $details, array(), $other_tables, $table);
            }
            return $rows;
        } else {
        	if ($limit)
				$this->db->limit($limit);
            $this->db->order_by($order_by);
            $query = $this->db->get($table);
            if ($query->num_rows()) {
                $rows = array();
                foreach ($query->result_array() as $row) {
                    $rows[] = $this->get_row($row['id'], $table, $details, array(), $other_tables, $table);
                }
                return $rows;
            } else {
                return FALSE;
            }
        }
    }
    
    function option_list($table, $ids = array(), $order_by = "id asc", $element = "title") {
        if (count($ids)) {
            $this->db->where_in('id', $ids);
        }
        $this->db->order_by($order_by);
        $query = $this->db->get($table);
        if ($query->num_rows()) {
            $list = "";
            foreach ($query->result_array() as $option) {
                $list .= "<option value='".$option['id']."'>".$option[$element]."</option>\n";
            }
            return $list;
        } else {
            return FALSE;
        }
    }
}

/* End of file common_db.php */
/* Location: ./system/application/models/common_db.php */
